TOLIMAN
=======
The goal of the TOLIMAN mission is to answer the question: is there a planet
around Alpha Centauri? The critical advance represented by the TOLIMAN 
telescope is its ability to assess a specific star. Until now telescopes have
been designed to survey many stars and confirm (with biases) which ones may 
have exoplanets. None have chosen a star and tried to resolutely and without 
question find all and any exoplanets in orbit. 
